@@ -1,32 +1,6 @@
-/*
-  Copyright 2008 Larry Gritz and the other authors and contributors.
-  All Rights Reserved.
-
-  Redistribution and use in source and binary forms, with or without
-  modification, are permitted provided that the following conditions are
-  met:
-  * Redistributions of source code must retain the above copyright
-    notice, this list of conditions and the following disclaimer.
-  * Redistributions in binary form must reproduce the above copyright
-    notice, this list of conditions and the following disclaimer in the
-    documentation and/or other materials provided with the distribution.
-  * Neither the name of the software's owners nor the names of its
-    contributors may be used to endorse or promote products derived from
-    this software without specific prior written permission.
-  THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
-  "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
-  LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
-  A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
-  OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
-  SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
-  LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
-  DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
-  THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
-  (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
-  OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
-
-  (This is the Modified BSD License)
-*/
+// Copyright 2008-present Contributors to the OpenImageIO project.
+// SPDX-License-Identifier: BSD-3-Clause
+// https://github.com/OpenImageIO/oiio/blob/master/LICENSE.md
 
 
 #include <cmath>
@@ -45,6 +19,7 @@
 #include <OpenImageIO/imagebufalgo.h>
 #include <OpenImageIO/imageio.h>
 #include <OpenImageIO/strutil.h>
+#include <OpenImageIO/sysutil.h>
 
 #ifdef USE_BOOST_REGEX
 #    include <boost/regex.hpp>
@@ -652,6 +627,10 @@ parse_files(int argc, const char* argv[])
 int
 main(int argc, const char* argv[])
 {
+    // Helpful for debugging to make sure that any crashes dump a stack
+    // trace.
+    Sysutil::setup_crash_stacktrace("stdout");
+
     Filesystem::convert_native_arguments(argc, (const char**)argv);
     ArgParse ap;
     // clang-format off
@@ -661,7 +640,7 @@ main(int argc, const char* argv[])
                 "%*", parse_files, "",
                 "--help", &help, "Print help message",
                 "-v", &verbose, "Verbose output",
-                "-m %s", &metamatch, "Metadata names to print (default: all)",
+                "-m %s:NAMES", &metamatch, "Metadata names to print (default: all)",
                 "-f", &filenameprefix, "Prefix each line with the filename",
                 "-s", &sum, "Sum the image sizes",
                 "-a", &subimages, "Print info about all subimages",
@@ -672,11 +651,7 @@ main(int argc, const char* argv[])
     if (ap.parse(argc, argv) < 0 || filenames.empty()) {
         std::cerr << ap.geterror() << std::endl;
         ap.usage();
-        return EXIT_FAILURE;
-    }
-    if (help) {
-        ap.usage();
-        exit(EXIT_FAILURE);
+        return help ? EXIT_SUCCESS : EXIT_FAILURE;
     }
 
     if (!metamatch.empty()) {
@@ -695,6 +670,7 @@ main(int argc, const char* argv[])
         longestname = std::max(longestname, s.length());
     longestname = std::min(longestname, (size_t)40);
 
+    int returncode      = EXIT_SUCCESS;
     long long totalsize = 0;
     for (auto&& s : filenames) {
         auto in = ImageInput::open(s);
@@ -703,6 +679,7 @@ main(int argc, const char* argv[])
             if (err.empty())
                 err = Strutil::sprintf("Could not open \"%s\"", s);
             std::cerr << "iinfo ERROR: " << err << "\n";
+            returncode = EXIT_FAILURE;
             continue;
         }
         ImageSpec spec = in->spec();
@@ -717,5 +694,5 @@ main(int argc, const char* argv[])
             printf("Total size: %.2f MB\n", t);
     }
 
-    return 0;
+    return returncode;
 }
