@@ -201,12 +201,11 @@ Filesystem::searchpath_find(const std::string& filename_utf8,
             return pathstr(f);
         }
 
-
         if (recursive && filesystem::is_directory(d, ec)) {
             std::vector<std::string> subdirs;
-            for (filesystem::directory_iterator s(d), end_iter; s != end_iter;
-                 ++s) {
-                if (filesystem::is_directory(s->status())) {
+            for (filesystem::directory_iterator s(d, ec), end_iter;
+                 !ec && s != end_iter; ++s) {
+                if (filesystem::is_directory(s->path(), ec)) {
                     subdirs.push_back(pathstr(s->path()));
                 }
             }
@@ -240,15 +239,17 @@ Filesystem::get_directory_entries(const std::string& dirname,
     }
 
     if (recursive) {
-        for (filesystem::recursive_directory_iterator s(dirpath);
-             s != filesystem::recursive_directory_iterator(); ++s) {
+        error_code ec;
+        for (filesystem::recursive_directory_iterator s(dirpath, ec);
+             !ec && s != filesystem::recursive_directory_iterator(); ++s) {
             std::string file = pathstr(s->path());
             if (!filter_regex.size() || regex_search(file, re))
                 filenames.push_back(file);
         }
     } else {
-        for (filesystem::directory_iterator s(dirpath);
-             s != filesystem::directory_iterator(); ++s) {
+        error_code ec;
+        for (filesystem::directory_iterator s(dirpath, ec);
+             !ec && s != filesystem::directory_iterator(); ++s) {
             std::string file = pathstr(s->path());
             if (!filter_regex.size() || regex_search(file, re))
                 filenames.push_back(file);
@@ -712,7 +713,7 @@ Filesystem::enumerate_file_sequence(const std::string& pattern,
                                     const std::vector<string_view>& views,
                                     std::vector<std::string>& filenames)
 {
-    ASSERT(views.size() == 0 || views.size() == numbers.size());
+    OIIO_ASSERT(views.size() == 0 || views.size() == numbers.size());
     filenames.clear();
     for (size_t i = 0, e = numbers.size(); i < e; ++i) {
         std::string f = pattern;
@@ -851,9 +852,9 @@ Filesystem::scan_for_matching_filenames(const std::string& pattern_,
     try {
         regex pattern_re(pattern_re_str);
 
-        for (filesystem::directory_iterator it(u8path(directory)), end_it;
-             it != end_it; ++it) {
-            error_code ec;
+        error_code ec;
+        for (filesystem::directory_iterator it(u8path(directory), ec), end_it;
+             !ec && it != end_it; ++it) {
             if (filesystem::is_regular(it->path(), ec)) {
                 const std::string f = pathstr(it->path());
                 match_results<std::string::const_iterator> frame_match;
